@@ -24,16 +24,16 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V18::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V18::Resources::Campaign;
-use Google::Ads::GoogleAds::V18::Resources::NetworkSettings;
-use Google::Ads::GoogleAds::V18::Common::ManualCpc;
-use Google::Ads::GoogleAds::V18::Enums::BudgetDeliveryMethodEnum   qw(STANDARD);
-use Google::Ads::GoogleAds::V18::Enums::AdvertisingChannelTypeEnum qw(SEARCH);
-use Google::Ads::GoogleAds::V18::Enums::CampaignStatusEnum         qw(PAUSED);
+use Google::Ads::GoogleAds::V19::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V19::Resources::Campaign;
+use Google::Ads::GoogleAds::V19::Resources::NetworkSettings;
+use Google::Ads::GoogleAds::V19::Common::ManualCpc;
+use Google::Ads::GoogleAds::V19::Enums::BudgetDeliveryMethodEnum   qw(STANDARD);
+use Google::Ads::GoogleAds::V19::Enums::AdvertisingChannelTypeEnum qw(SEARCH);
+use Google::Ads::GoogleAds::V19::Enums::CampaignStatusEnum         qw(PAUSED);
 use
-  Google::Ads::GoogleAds::V18::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V18::Services::CampaignService::CampaignOperation;
+  Google::Ads::GoogleAds::V19::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V19::Services::CampaignService::CampaignOperation;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -57,7 +57,7 @@ sub add_campaigns {
   # [START add_campaigns]
   # Create a campaign budget, which can be shared by multiple campaigns.
   my $campaign_budget =
-    Google::Ads::GoogleAds::V18::Resources::CampaignBudget->new({
+    Google::Ads::GoogleAds::V19::Resources::CampaignBudget->new({
       name           => "Interplanetary budget #" . uniqid(),
       deliveryMethod => STANDARD,
       amountMicros   => 500000
@@ -65,7 +65,7 @@ sub add_campaigns {
 
   # Create a campaign budget operation.
   my $campaign_budget_operation =
-    Google::Ads::GoogleAds::V18::Services::CampaignBudgetService::CampaignBudgetOperation
+    Google::Ads::GoogleAds::V19::Services::CampaignBudgetService::CampaignBudgetOperation
     ->new({create => $campaign_budget});
 
   # Add the campaign budget.
@@ -76,7 +76,7 @@ sub add_campaigns {
 
   # [START add_campaigns_1]
   # Create a campaign.
-  my $campaign = Google::Ads::GoogleAds::V18::Resources::Campaign->new({
+  my $campaign = Google::Ads::GoogleAds::V19::Resources::Campaign->new({
       name                   => "Interplanetary Cruise #" . uniqid(),
       advertisingChannelType => SEARCH,
       # Recommendation: Set the campaign to PAUSED when creating it to stop
@@ -84,13 +84,11 @@ sub add_campaigns {
       # targeting and the ads are ready to serve.
       status => PAUSED,
       # Set the bidding strategy and budget.
-      manualCpc => Google::Ads::GoogleAds::V18::Common::ManualCpc->new(
-        {enhancedCpcEnabled => "true"}
-      ),
+      manualCpc      => Google::Ads::GoogleAds::V19::Common::ManualCpc->new(),
       campaignBudget => $campaign_budgets_response->{results}[0]{resourceName},
       # Set the campaign network options.
       networkSettings =>
-        Google::Ads::GoogleAds::V18::Resources::NetworkSettings->new({
+        Google::Ads::GoogleAds::V19::Resources::NetworkSettings->new({
           targetGoogleSearch  => "true",
           targetSearchNetwork => "true",
           # Enable Display Expansion on Search campaigns. See
@@ -108,7 +106,7 @@ sub add_campaigns {
 
   # Create a campaign operation.
   my $campaign_operation =
-    Google::Ads::GoogleAds::V18::Services::CampaignService::CampaignOperation->
+    Google::Ads::GoogleAds::V19::Services::CampaignService::CampaignOperation->
     new({create => $campaign});
 
   # Add the campaign.
